==> primevue-3.46.0.tgz: package/icons/pencil/index.js <==
this.primevue = this.primevue || {};
this.primevue.icons = this.primevue.icons || {};
this.primevue.icons.pencil = (function (BaseIcon, utils, vue) {
    'use strict';

    function _interopDefaultLegacy (e) { return e && typeof e === 'object' && 'default' in e ? e : { 'default': e }; }

    var BaseIcon__default = /*#__PURE__*/_interopDefaultLegacy(BaseIcon);

    var script = {
      name: 'PencilIcon',
      "extends": BaseIcon__default["default"],
      computed: {
        pathId: function pathId() {
          return "pv_icon_clip_".concat(utils.UniqueComponentId());
        }
      }
    };

    var _hoisted_1 = ["clip-path"];
    var _hoisted_2 = /*#__PURE__*/vue.createElementVNode("path", {
      d: "M0.609628 13.959C0.530658 13.9599 0.452305 13.9451 0.379077 13.9156C0.305849 13.8861 0.239191 13.8424 0.18294 13.787C0.118447 13.7234 0.0688234 13.6464 0.0376166 13.5614C0.00640987 13.4765 -0.00560954 13.3857 0.00241768 13.2956L0.25679 10.1501C0.267698 10.0041 0.331934 9.86709 0.437312 9.76516L9.51265 0.705715C10.0183 0.233014 10.6911 -0.0203041 11.3835 0.00127367C12.0714 0.00660201 12.7315 0.27311 13.2298 0.746671C13.7076 1.23651 13.9824 1.88848 13.9992 2.57201C14.0159 3.25554 13.7733 3.92015 13.32 4.4327L4.23648 13.5331C4.13482 13.6342 4.0017 13.6978 3.85903 13.7133L0.667067 14L0.609628 13.959ZM1.43018 10.4696L1.25787 12.714L3.50619 12.5092L12.4502 3.56444C12.6246 3.35841 12.7361 3.10674 12.7714 2.83933C12.8067 2.57193 12.7644 2.30002 12.6495 2.05591C12.5346 1.8118 12.3519 1.60575 12.1231 1.46224C11.8943 1.31873 11.6291 1.2438 11.3589 1.24633C11.1813 1.23508 11.0033 1.25975 10.8355 1.31887C10.6677 1.37798 10.5136 1.47033 10.3824 1.59036L1.43018 10.4696Z",
      fill: "currentColor"
    }, null, -1);
    var _hoisted_3 = [_hoisted_2];
    var _hoisted_4 = ["id"];
    var _hoisted_5 = /*#__PURE__*/vue.createElementVNode("rect", {
      width: "14",
      height: "14",
      fill: "white"
    }, null, -1);
    var _hoisted_6 = [_hoisted_5];
    function render(_ctx, _cache, $props, $setup, $data, $options) {
      return vue.openBlock(), vue.createElementBlock("svg", vue.mergeProps({
        width: "14",
        height: "14",
        viewBox: "0 0 14 14",
        fill: "none",
        xmlns: "http://www.w3.org/2000/svg"
      }, _ctx.pti()), [vue.createElementVNode("g", {
        "clip-path": "url(#".concat($options.pathId, ")")
      }, _hoisted_3, 8, _hoisted_1), vue.createElementVNode("defs", null, [vue.createElementVNode("clipPath", {
        id: "".concat($options.pathId)
      }, _hoisted_6, 8, _hoisted_4)])], 16);
    }

    script.render = render;

    return script;

})(primevue.baseicon, primevue.utils, Vue);

==> primevue-3.47.0.tgz: package/icons/pencil/index.js <==
this.primevue = this.primevue || {};
this.primevue.icons = this.primevue.icons || {};
this.primevue.icons.pencil = (function (BaseIcon, vue) {
    'use strict';

    function _interopDefaultLegacy (e) { return e && typeof e === 'object' && 'default' in e ? e : { 'default': e }; }

    var BaseIcon__default = /*#__PURE__*/_interopDefaultLegacy(BaseIcon);

    var script = {
      name: 'PencilIcon',
      "extends": BaseIcon__default["default"]
    };

    var _hoisted_1 = ["clip-path"];
    var _hoisted_2 = /*#__PURE__*/vue.createElementVNode("path", {
      d: "M0.609628 13.959C0.530658 13.9599 0.452305 13.9451 0.379077 13.9156C0.305849 13.8861 0.239191 13.8424 0.18294 13.787C0.118447 13.7234 0.0688234 13.6464 0.0376166 13.5614C0.00640987 13.4765 -0.00560954 13.3857 0.00241768 13.2956L0.25679 10.1501C0.267698 10.0041 0.331934 9.86709 0.437312 9.76516L9.51265 0.705715C10.0183 0.233014 10.6911 -0.0203041 11.3835 0.00127367C12.0714 0.00660201 12.7315 0.27311 13.2298 0.746671C13.7076 1.23651 13.9824 1.88848 13.9992 2.57201C14.0159 3.25554 13.7733 3.92015 13.32 4.4327L4.23648 13.5331C4.13482 13.6342 4.0017 13.6978 3.85903 13.7133L0.667067 14L0.609628 13.959ZM1.43018 10.4696L1.25787 12.714L3.50619 12.5092L12.4502 3.56444C12.6246 3.35841 12.7361 3.10674 12.7714 2.83933C12.8067 2.57193 12.7644 2.30002 12.6495 2.05591C12.5346 1.8118 12.3519 1.60575 12.1231 1.46224C11.8943 1.31873 11.6291 1.2438 11.3589 1.24633C11.1813 1.23508 11.0033 1.25975 10.8355 1.31887C10.6677 1.37798 10.5136 1.47033 10.3824 1.59036L1.43018 10.4696Z",
      fill: "currentColor"
    }, null, -1);
    var _hoisted_3 = [_hoisted_2];
    var _hoisted_4 = ["id"];
    var _hoisted_5 = /*#__PURE__*/vue.createElementVNode("rect", {
      width: "14",
      height: "14",
      fill: "white"
    }, null, -1);
    var _hoisted_6 = [_hoisted_5];
    function render(_ctx, _cache, $props, $setup, $data, $options) {
      return vue.openBlock(), vue.createElementBlock("svg", vue.mergeProps({
        width: "14",
        height: "14",
        viewBox: "0 0 14 14",
        fill: "none",
        xmlns: "http://www.w3.org/2000/svg"
      }, _ctx.pti()), [vue.createElementVNode("g", {
        "clip-path": "url(#".concat(_ctx.pathId, ")")
      }, _hoisted_3, 8, _hoisted_1), vue.createElementVNode("defs", null, [vue.createElementVNode("clipPath", {
        id: "".concat(_ctx.pathId)
      }, _hoisted_6, 8, _hoisted_4)])], 16);
    }

    script.render = render;

    return script;

})(primevue.baseicon, Vue);
